/*
 * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
 * @license AGPL-3.0
 *
 * This code is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
 *
 * Any use of the work other than as authorized under this license or copyright law is prohibited.
 *
 */

package com.openexchange.messaging.rss;

import java.util.ArrayList;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;
import com.openexchange.exception.OXException;
import com.openexchange.session.Session;
import com.sun.syndication.feed.synd.SyndEntry;
import com.sun.syndication.feed.synd.SyndFeed;


/**
 * {@link FeedAdapter}
 *
 * @author <a href="mailto:francisco.laguna@open-xchange.com">Francisco Laguna</a>
 */
public class FeedAdapter {

    private final Map<String, SyndMessage> messages = new LinkedHashMap<String, SyndMessage>();

    public FeedAdapter(final SyndFeed feed, final String folder, final Session session) throws OXException {
        final List<SyndEntry> entries = feed.getEntries();
        for (final SyndEntry syndEntry : entries) {
            remember(new SyndMessage(feed, syndEntry, folder, session));
        }
    }

    private void remember(final SyndMessage syndMessage) {
        messages.put(syndMessage.getId(), syndMessage);
    }

    public SyndMessage get(final String id) {
        return messages.get(id);
    }

    public List<SyndMessage> getMessages() {
        return new ArrayList<SyndMessage>(messages.values());
    }


}
